@@ -7,7 +7,7 @@ use ExtUtils::Manifest ();
 
 use vars qw{$VERSION @ISA $ISCORE};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.01';
 	@ISA     = 'Module::Install::Base';
 	$ISCORE  = 1;
 }
@@ -21,7 +21,7 @@ sub install_share {
 	}
 	unless ( defined $dir and -d $dir ) {
     		require Carp;
-		Carp::croak("Illegal or missing directory install_share param");
+		Carp::croak("Illegal or missing directory install_share param: '$dir'");
 	}
 
 	# Split by type
